-- buy production inputs

local function dialogCallback(self, yes, fillType, newFillLevel, price)
	if yes then
		g_currentMission:addMoney(-price, self.playerFarm.farmId, MoneyType.PRODUCTION_COSTS, true)

		self.selectedProductionPoint.storage:setFillLevel(newFillLevel, fillType)
		self.storageList:reloadData()
	end
end

local function buttonCallback(self, fillType)
	local currentFillLevel = self.selectedProductionPoint.storage:getFillLevel(fillType)
	local missingFillLevel = self.selectedProductionPoint.storage:getFreeCapacity(fillType)
	local buyVolume = math.min(missingFillLevel, math.max(1000, currentFillLevel))
	local buyVolumeText = self.i18n:formatVolume(buyVolume, 0)
	local fillTypeName = g_fillTypeManager:getFillTypeByIndex(fillType).title
	local pricePerLiter = g_fillTypeManager:getFillTypeByIndex(fillType).pricePerLiter
	local price = pricePerLiter * buyVolume * g_currentMission.missionInfo.buyPriceMultiplier * 2
	local priceText = self.i18n:formatMoney(price, 0, true, true)
	local question = buyVolumeText.." "..fillTypeName.." ("..priceText..")?"

	g_gui:showYesNoDialog({
		text = question,
		title = self.i18n:getText("button_buy"),
		callback = function(yes)
			dialogCallback(self, yes, fillType, currentFillLevel + buyVolume, price)
		end
	})
end

local function updateMenuButtons(self)
	local isProductionListActive = self.productionList == FocusManager:getFocusedElement()
	local fillType, isInput = self:getSelectedStorageFillType()

	if not isProductionListActive and fillType ~= FillType.UNKNOWN and isInput then
		table.insert(self.menuButtonInfo, {
			profile = "buttonOk",
			inputAction = InputAction.MENU_ACCEPT,
			text = self.i18n:getText("button_buy"),
			callback = function()
				buttonCallback(self, fillType)
			end
		})

		self:setMenuButtonInfoDirty()
	end
end

InGameMenuProductionFrame.updateMenuButtons = Utils.appendedFunction(InGameMenuProductionFrame.updateMenuButtons, updateMenuButtons)
